@@ -28,3 +28,7 @@ class TestDjangoTestingModel:
     def test_max_lenght(self):
         new_obj = DjangoTestingModel.create(FKTestingModel)
         assert new_obj.integer_test < 5
+
+    def test_datetime(self):
+        new_obj = DjangoTestingModel.create(FKTestingModel)
+        assert new_obj.datetime_test < 5
